#
# spec file for package budgie-screensaver
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Callum Farmer <gmbr3@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _distconfdir %{_sysconfdir}
%endif
Name:           budgie-screensaver
Version:        5.1.0+0
Release:        5.3
Summary:        Fork of GNOME Screensaver for Budgie 10
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/BuddiesOfBudgie/budgie-screensaver
Source0:        %{name}-%{version}.tar.xz
Patch0:         gnome-screensaver-suse-pam.patch
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libgnomekbdui)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       pam
Requires:       procps
%if 0%{?suse_version} < 1550
BuildRequires:  pkgconfig(xxf86misc)
%endif

%description
Fork of GNOME Screensaver for Budgie 10

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
mv %{buildroot}%{_datadir}/applications/budgie-screensaver.desktop %{buildroot}%{_datadir}/applications/org.buddiesofbudgie.BudgieDesktopScreensaver.desktop
mkdir -p %{buildroot}%{_distconfdir}/xdg/autostart
cp %{buildroot}%{_datadir}/applications/org.buddiesofbudgie.BudgieDesktopScreensaver.desktop %{buildroot}%{_distconfdir}/xdg/autostart/org.buddiesofbudgie.BudgieDesktopScreensaver.desktop
%find_lang budgie-screensaver
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
mv %{buildroot}%{_sysconfdir}/pam.d/budgie-screensaver %{buildroot}%{_pam_vendordir}

%pre
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/budgie-screensaver ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/budgie-screensaver ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%files
%license LICENSE
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/budgie-screensaver
%else
%config(noreplace) %{_sysconfdir}/pam.d/budgie-screensaver
%endif
%{_bindir}/budgie-screensaver
%{_bindir}/budgie-screensaver-command
%{_libexecdir}/budgie-screensaver-dialog
%{_datadir}/applications/org.buddiesofbudgie.BudgieDesktopScreensaver.desktop
%{_distconfdir}/xdg/autostart/org.buddiesofbudgie.BudgieDesktopScreensaver.desktop
%{_mandir}/man1/budgie-screensaver-command.1%{?ext_man}
%{_mandir}/man1/budgie-screensaver.1%{?ext_man}

%files lang -f budgie-screensaver.lang

%changelog
* Thu Feb  1 2024 Callum Farmer <gmbr3@opensuse.org>
- Move autostart back to %%_distconfdir as aaa_base is fixed
- Use new budgie namespace for desktop file aswell
* Thu Feb  9 2023 Callum Farmer <gmbr3@opensuse.org>
- Use new budgie namespace for XDG autostart
* Thu Jan 12 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Remove unused %%chkpwd
* Thu Nov 24 2022 gmbr3@opensuse.org
- Update to version 5.1.0+0:
  * Bump version
  * Move mkrelease.sh to scripts folder
  * Use GdkSeat to grab input
  * Resolve most compiler warnings
  * Add back options for xf86gamma, no-locking, and consolekit
  * Use bullet for invisible char in entry.
  * Add History section to README
* Mon Aug 29 2022 Callum Farmer <gmbr3@opensuse.org>
- Move autostart back to /etc until aaa_base is fixed
* Thu Jul 14 2022 gmbr3@opensuse.org
- Update to version 5.0.2+0:
  * Bump version
  * Clarify that Meson is used, not Autotools
  * Add libgnomekbd-dev to Actions workflow
  * Re-add build option to disable keyboard layout indicator
* Fri May 27 2022 gmbr3@opensuse.org
- Update to version 5.0.1+0:
  * Version bump
  * Fix musl build
  * Add our mkrelease script that we use on budgie-desktop-view
    and budgie-desktop itself
* Tue Mar  8 2022 gmbr3@opensuse.org
- Update to version 5.0+0:
  * Unalign versioning with budgie-desktop
  * Format header files using clang-format
  * Update indentation from 8 spaces to tabs
  * Add FUNDING.yml
  * Add badges to README and update header
  * Implement GitHub Actions pipeline
  * Use S_ISDIR for PAM auth
  * Change C STD to C11 from GNU11
  * Remove spurious directive in Meson, add comment
  * Update README compiling instructions
  * Remove unused test C files
  * Remove unused files
  * Convert to Meson
- Remove GNU autotools and add meson BRs
- Removed old patches:
  * remove-old-automake-macros.patch
  * gnome-screensaver-helper.patch
  * gnome-screensaver-xvkbd-on-lock.patch
  * gnome-screensaver-multihead-unlock.patch
* Fri Jan  7 2022 gmbr3@opensuse.org
- Update to version 4.0+2:
  * Sort out renames
  * Have a couple deferred re-attempts to kill gjs.
  * Remove dbus service file as it results in a race condition with
    gnome-settings-daemon that can cause double prompts.
  * Fix Makefile for distcheck + dist
* Sat May 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix missed change in gnome-screensaver-helper.patch
* Wed Apr 28 2021 gmbr3@opensuse.org
- Update to version 4.0+0:
  * Remove dbus service file as it results in a race condition
    with gnome-settings-daemon that can cause double prompts
  * Fix Makefile for distcheck + dist
  * Bump to 4.0
  * Move logic of check to main
  * Check our environment to see if we are running on Budgie
    before going forward
  * Explicitly kill gjs before requesting name
  * Add back required AUTHORS file
  * Add back README with ref to repo
  * Update data and cleanup misc outdated files
  * Update to more appropriate README
  * Update make output message for budgie-screensaver
  * Update to budgie-screensaver
  * Update GNOME references to BUDGIE
* Thu Apr 15 2021 gmbr3@opensuse.org
- Update to version 20210412 (again):
  * Rename service file to not conflict with gnome-shell.
  * Revert "Change dbus name to us.getsol.budgie-screensaver"
* Mon Apr 12 2021 gmbr3@opensuse.org
- Update to version 20210412:
  * Change dbus name to us.getsol.budgie-screensaver
- Remove GNOME-40.patch: merged
* Sun Apr 11 2021 Callum Farmer <gmbr3@opensuse.org>
- Add GNOME-40.patch: to fix conflict with GNOME 40
* Fri Apr  9 2021 Callum Farmer <gmbr3@opensuse.org>
- Prepare usrmerge
* Wed Dec  9 2020 Callum Farmer <gmbr3@opensuse.org>
- Removed gnome-desktop-3.36.patch: contained in upstream
- Update to version 20201110
  * Updated for new gnome versions
* Sat Sep 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Use a better format for testing gnome versions
* Fri Aug 28 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Initial packaging version 20190923
- Add patches from gnome-screensaver in openSUSE 12.3 :)
  * gnome-screensaver-suse-pam.patch
  * gnome-screensaver-helper.patch (bgo#640647)
  * gnome-screensaver-xvkbd-on-lock.patch
  * gnome-screensaver-multihead-unlock.patch (bnc#444157,bgo#455118)
- Add remove-old-automake-macros.patch: fix Automake problems
